@@ -1,7 +1,6 @@
 from math import ceil
 from typing import Dict, Iterator, Optional
 
-import numpy as np
 from maggma.builders import Builder
 from maggma.stores import Store
 from maggma.utils import grouper
@@ -74,9 +73,9 @@ class MagneticBuilder(Builder):
         mat_ids = self.materials.distinct(self.materials.key, criteria=q)
         mag_ids = self.magnetism.distinct(self.magnetism.key)
 
-        mats_set = set(
-            self.magnetism.newer_in(target=self.materials, criteria=q, exhaustive=True)
-        ) | (set(mat_ids) - set(mag_ids))
+        mats_set = set(self.magnetism.newer_in(target=self.materials, criteria=q, exhaustive=True)) | (
+            set(mat_ids) - set(mag_ids)
+        )
 
         mats = [mat for mat in mats_set]
 
@@ -141,9 +140,7 @@ class MagneticBuilder(Builder):
         )
 
         task_updated = task_query["last_updated"]
-        total_magnetization = task_query["calcs_reversed"][-1]["output"]["outcar"][
-            "total_magnetization"
-        ]
+        total_magnetization = task_query["calcs_reversed"][-1]["output"]["outcar"]["total_magnetization"]
 
         mat_doc.update(
             {
