@@ -237,7 +237,7 @@ class MoleculesAssociationBuilder(Builder):
                 doc = MoleculeDoc.construct_deprecated_molecule(tasks)
                 doc.warnings.append(str(e))
                 molecules.append(doc)
-                self.logger.warn(
+                self.logger.warning(
                     f"Failed making material for {failed_ids}."
                     f" Inserted as deprecated molecule: {doc.molecule_id}"
                 )
